;+
; NAME:
;  rdrawast
; PURPOSE:
;  Read raw astrometry data file.
; DESCRIPTION:
;
; CATEGORY:
;  File I/O
; CALLING SEQUENCE:
;  rdrawast,file,fn,jd,ra,dec,mag,nobs
; INPUTS:
;  file - Astrometry data file to be read.
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;  fn  - Original filename for measurement
;  jd  - Julian date of measurement
;  ra  - Right Ascension (radians)
;  dec - Declination (radians)
;  mag - measured magnitude
;  nobs - Number of measurements.  (zero if file not found or file empty).
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;  98/01/13, Written by Marc W. Buie, Lowell Observatory
;-
pro rdrawast,file,fn,jd,ra,dec,mag,nobs

   if not exists(file) then begin
      print,'File: ',file,' does not exists.  Unable to continue.'
      nobs=0
      return
   endif

   openr,lun,file,/get_lun
   nobs=0
   line=''
   WHILE not eof(lun) DO BEGIN
      readf,lun,line,format='(a)'
      nobs=nobs+1
   ENDWHILE
   point_lun,lun,0

   fn=strarr(nobs)
   jd=dblarr(nobs)
   ra=dblarr(nobs)
   dec=dblarr(nobs)
   mag=fltarr(nobs)

   FOR i=0,nobs-1 DO BEGIN
      readf,lun,line,format='(a)'
      words=str_sep(line,' ')

      fn[i]=words[0]
      jd[i]=double(words[1])
      ra[i]=raparse(words[2])
      dec[i]=decparse(words[3])
      mag[i]=float(words[4])
   ENDFOR

   free_lun,lun
   
end

